@@ -1,7 +1,7 @@
-from typing import Tuple
+from __future__ import annotations
 from Crypto.Cipher import ChaCha20_Poly1305
-from ..rfc7516.registry import JWERegistry
-from ..rfc7516.models import JWEEncModel
+from .._rfc7516.registry import JWERegistry
+from .._rfc7516.models import JWEEncModel
 
 __all__ = ["ChaCha20EncModel", "JWE_ENC_MODELS", "register_chaha20_poly1305"]
 
@@ -16,9 +16,8 @@ class ChaCha20EncModel(JWEEncModel):
         self.description = description
         self.iv_size = iv_size
 
-    def encrypt(self, plaintext: bytes, cek: bytes, iv: bytes, aad: bytes) -> Tuple[bytes, bytes]:
-        """Key Encryption with AEAD_CHACHA20_POLY1305
-        """
+    def encrypt(self, plaintext: bytes, cek: bytes, iv: bytes, aad: bytes) -> tuple[bytes, bytes]:
+        """Key Encryption with AEAD_CHACHA20_POLY1305"""
         chacha = ChaCha20_Poly1305.new(key=cek, nonce=iv)
         chacha.update(aad)
         ciphertext, tag = chacha.encrypt_and_digest(plaintext)
